← Back to team overview

launchpad-reviewers team mailing list archive

[Merge] lp:~maxiberta/launchpad/sitesearch-default-bing into lp:launchpad

 

Maximiliano Bertacchini has proposed merging lp:~maxiberta/launchpad/sitesearch-default-bing into lp:launchpad.

Commit message:
Make Bing the default site search engine.

Requested reviews:
  Launchpad code reviewers (launchpad-reviewers)

For more details, see:
https://code.launchpad.net/~maxiberta/launchpad/sitesearch-default-bing/+merge/342473

Make Bing the default site search engine, now that it's been successfully deployed.
-- 
Your team Launchpad code reviewers is requested to review the proposed merge of lp:~maxiberta/launchpad/sitesearch-default-bing into lp:launchpad.
=== modified file 'lib/lp/app/browser/root.py'
--- lib/lp/services/features/flags.py	2018-03-28 12:52:32 +0000
+++ lib/lp/services/features/flags.py	2018-03-30 23:13:48 +0000
@@ -237,7 +237,7 @@
     ('sitesearch.engine.name',
      'space delimited',
      'Name of the site search engine backend ("google" or "bing").',
-     'google',
+     'bing',
      'Site search engine',
      ''),
     ])


Follow ups
--- lib/lp/app/browser/root.py	2018-03-28 12:52:32 +0000
+++ lib/lp/app/browser/root.py	2018-03-30 23:13:48 +0000
@@ -517,8 +517,8 @@
         if query_terms in [None, '']:
             return None
         search_engine = getFeatureFlag("sitesearch.engine.name")
-        # Default to the Google search engine.
-        search_engine = search_engine or "google"
+        # Default to the Bing search engine.
+        search_engine = search_engine or "bing"
         site_search = getUtility(ISearchService, name=search_engine)
         try:
             page_matches = site_search.search(

=== modified file 'lib/lp/services/features/flags.py'